Module sample

Module sample 

Sample and tensor data structures exchanged between pipeline stages. Sample - the unit of data that flows through the pipeline.

Structs

Sample
A single training sample - a named collection of data buffers.
SampleMetadata
Metadata about where a sample came from.
Tensor
A typed, shaped buffer of data.

Enums

DType
Supported element types.